@@ -1,4 +1,4 @@
-from typing import List, Optional
+from typing import List, Optional, Union
 from luga.artifacts import fmodel, beautify_one, beautify_many, Language
 
 
@@ -10,11 +10,20 @@ def language(text: str, threshold: Optional[float] = 0.5) -> Language:
     return beautify_one(response=response, threshold=threshold)
 
 
-def languages(texts: List[str], threshold: Optional[float] = 0.5) -> List[Language]:
+def languages(
+    texts: List[str],
+    threshold: Optional[float] = 0.5,
+    only_language: Optional[bool] = False,
+) -> Union[List[str], List[Language]]:
 
     assert isinstance(
         texts, List
     ), f"text ought be type List[str], we got {type(texts)}"
 
-    responses = fmodel.predict(texts)
-    return beautify_many(responses=responses, threshold=threshold)
+    responses_ = fmodel.predict(texts)
+    responses = beautify_many(responses=responses_, threshold=threshold)
+
+    if only_language:
+        return [response.name for response in responses]
+
+    return responses
